==> xerces21_2.1.0.orig.tar.gz: xerces-c-src2_1_0/src/xercesc/dom/deprecated/DocumentFragmentImpl.cpp <==
/*
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xerces" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache\@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation, and was
 * originally based on software copyright (c) 1999, International
 * Business Machines, Inc., http://www.ibm.com .  For more information
 * on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

/*
 * $Id: DocumentFragmentImpl.cpp,v 1.2 2002/05/21 20:15:00 tng Exp $
 */

#include "DocumentFragmentImpl.hpp"
#include "DOM_Node.hpp"
#include "DOM_DOMException.hpp"
#include "DStringPool.hpp"


static DOMString *nam = 0;   // Will be lazily initialized to "#document-fragment"
static XMLRegisterCleanup namCleanup;

DocumentFragmentImpl::DocumentFragmentImpl(DocumentImpl *masterDoc)
    : ParentNode(masterDoc)
{
};


DocumentFragmentImpl::DocumentFragmentImpl(const DocumentFragmentImpl &other,
                                           bool deep)
    : ParentNode(other)
{
    if (deep)
        cloneChildren(other);
};


DocumentFragmentImpl::~DocumentFragmentImpl()
{
};



NodeImpl *DocumentFragmentImpl::cloneNode(bool deep)
{
    return new DocumentFragmentImpl(*this, deep);
};


DOMString DocumentFragmentImpl::getNodeName() {
    return DStringPool::getStaticString("#document-fragment"
                                       , &nam
                                       , reinitDocumentFragmentImpl
                                       , namCleanup);
}


short DocumentFragmentImpl::getNodeType() {
    return DOM_Node::DOCUMENT_FRAGMENT_NODE;
};


bool DocumentFragmentImpl::isDocumentFragmentImpl()
{
        return true;
};


// -----------------------------------------------------------------------
//  Notification that lazy data has been deleted
// -----------------------------------------------------------------------
void DocumentFragmentImpl::reinitDocumentFragmentImpl() {
	delete nam;
	nam = 0;
}

==> xerces25_2.5.0.orig.tar.gz: xerces-c-src_2_5_0/src/xercesc/dom/deprecated/DocumentFragmentImpl.cpp <==
/*
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xerces" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache\@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation, and was
 * originally based on software copyright (c) 1999, International
 * Business Machines, Inc., http://www.ibm.com .  For more information
 * on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

/*
 * $Id: DocumentFragmentImpl.cpp,v 1.4 2003/05/22 02:26:50 knoaman Exp $
 */

#include "DocumentFragmentImpl.hpp"
#include "DOM_Node.hpp"
#include "DOM_DOMException.hpp"
#include "DStringPool.hpp"
#include "DocumentImpl.hpp"

XERCES_CPP_NAMESPACE_BEGIN



static DOMString *nam = 0;   // Will be lazily initialized to "#document-fragment"
static XMLRegisterCleanup namCleanup;

DocumentFragmentImpl::DocumentFragmentImpl(DocumentImpl *masterDoc)
    : ParentNode(masterDoc)
{
};


DocumentFragmentImpl::DocumentFragmentImpl(const DocumentFragmentImpl &other,
                                           bool deep)
    : ParentNode(other)
{
    if (deep)
        cloneChildren(other);
};


DocumentFragmentImpl::~DocumentFragmentImpl()
{
};



NodeImpl *DocumentFragmentImpl::cloneNode(bool deep)
{
    return new (getOwnerDocument()->getMemoryManager()) DocumentFragmentImpl(*this, deep);
};


DOMString DocumentFragmentImpl::getNodeName() {
    return DStringPool::getStaticString("#document-fragment"
                                       , &nam
                                       , reinitDocumentFragmentImpl
                                       , namCleanup);
}


short DocumentFragmentImpl::getNodeType() {
    return DOM_Node::DOCUMENT_FRAGMENT_NODE;
};


bool DocumentFragmentImpl::isDocumentFragmentImpl()
{
        return true;
};


// -----------------------------------------------------------------------
//  Notification that lazy data has been deleted
// -----------------------------------------------------------------------
void DocumentFragmentImpl::reinitDocumentFragmentImpl() {
	delete nam;
	nam = 0;
}

XERCES_CPP_NAMESPACE_END
